# -*- encoding: utf-8 -*-
# rebookmaker v0.8.1
# EPUB generator
# Copyright © 2020, Shlomi Fish.
# See /LICENSE for licensing information.

"""
INSERT MODULE DESCRIPTION HERE.

:Copyright: © 2020, Shlomi Fish.
:License: BSD (see /LICENSE).
"""

__all__ = ()



# -*- encoding: utf-8 -*-
# rebookmaker v0.8.1
# EPUB generator
# Copyright © 2020, Shlomi Fish.
# See /LICENSE for licensing information.

"""
Main routine of rebookmaker.

:Copyright: © 2020, Shlomi Fish.
:License: BSD (see /LICENSE).
"""

__all__ = ('main',)


def main():
    """Main routine of rebookmaker."""
    print("Hello, world!")
    print("This is rebookmaker.")
    print("You should customize __main__.py to your liking (or delete it).")


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_rebook
----------------------------------

Tests for `rebookmaker` module.
"""

import pytest  # noqa: F401


def test_bhs():
    """Sample pytest test function with the pytest fixture as an argument.
    """
    import rebookmaker
    assert rebookmaker.EbookMaker()
